AdversarialBCEWithLogitsLoss
============================

.. currentmodule:: pykeen.losses

.. autoclass:: AdversarialBCEWithLogitsLoss
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AdversarialBCEWithLogitsLoss.negative_loss_term_unreduced
      ~AdversarialBCEWithLogitsLoss.positive_loss_term

   .. rubric:: Methods Documentation

   .. automethod:: negative_loss_term_unreduced
   .. automethod:: positive_loss_term
